@@ -1,13 +1,14 @@
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <stdio.h>
 #include <unistd.h>
 #include <string.h>
 
 #include <glib.h>
 
-#include <wocky/wocky-data-form.h>
-#include <wocky/wocky-stanza.h>
-#include <wocky/wocky-namespaces.h>
-#include <wocky/wocky-utils.h>
+#include <wocky/wocky.h>
 
 #include "wocky-test-helper.h"
 
