@@ -1,14 +1,14 @@
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <stdio.h>
 #include <unistd.h>
 #include <string.h>
 
 #include <glib.h>
 
-#include <wocky/wocky-pubsub-service.h>
-#include <wocky/wocky-pubsub-node.h>
-#include <wocky/wocky-utils.h>
-#include <wocky/wocky-namespaces.h>
-#include <wocky/wocky-xmpp-error.h>
+#include <wocky/wocky.h>
 
 #include "wocky-pubsub-test-helpers.h"
 #include "wocky-test-helper.h"
@@ -24,7 +24,7 @@ create_session (void)
 
   stream = g_object_new (WOCKY_TYPE_TEST_STREAM, NULL);
   connection = wocky_xmpp_connection_new (stream->stream0);
-  session = wocky_session_new (connection, "example.com");
+  session = wocky_session_new_with_connection (connection, "example.com");
 
   g_object_unref (connection);
   g_object_unref (stream);
