@@ -30,7 +30,7 @@
 #include <gio/gio.h>
 
 #include "wocky-test-sasl-auth-server.h"
-
+#include "wocky-test-helper.h"
 
 #ifdef HAVE_LIBSASL2
 
@@ -988,9 +988,7 @@ test_sasl_auth_server_stop (TestSaslAuthServer *self)
 
   if (priv->cancellable != NULL)
     {
-      if (!g_cancellable_is_cancelled (priv->cancellable))
-          g_cancellable_cancel (priv->cancellable);
-
+      test_cancel_in_idle (priv->cancellable);
       g_object_unref (priv->cancellable);
       priv->cancellable = NULL;
     }
