@@ -18,6 +18,10 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -52,6 +56,7 @@ typedef struct {
 typedef struct {
   GOutputStream parent;
   GAsyncQueue *queue;
+  WockyTestStreamWriteMode mode;
   GError *write_error /* no, this is not a coding style violation */;
   gboolean dispose_has_run;
 } WockyTestOutputStream;
@@ -72,7 +77,9 @@ typedef struct {
   gsize count;
   GError *read_error /* no, this is not a coding style violation */;
   gboolean dispose_has_run;
-  WockyTestSTreamReadMode mode;
+  WockyTestStreamReadMode mode;
+  WockyTestStreamDirectReadCb direct_read_cb;
+  gpointer direct_read_user_data;
   gboolean corked;
 } WockyTestInputStream;
 
@@ -286,7 +293,7 @@ wocky_test_input_stream_read (GInputStream *stream, void *buffer, gsize count,
 
     if (self->offset == self->out_array->len)
       {
-        g_array_free (self->out_array, TRUE);
+        g_array_unref (self->out_array);
         self->out_array = g_async_queue_try_pop (self->queue);
         self->offset = 0;
       }
@@ -297,33 +304,12 @@ wocky_test_input_stream_read (GInputStream *stream, void *buffer, gsize count,
   } while (self->mode != WOCK_TEST_STREAM_READ_EXACT
     && written < count && self->out_array != NULL);
 
+  if (self->direct_read_cb != NULL)
+    self->direct_read_cb (buffer, written, self->direct_read_user_data);
+
   return written;
 }
 
-static gssize
-wocky_test_input_stream_read_finish (GInputStream *stream,
-    GAsyncResult *result,
-    GError **error)
-{
-  WockyTestInputStream *self = WOCKY_TEST_INPUT_STREAM (stream);
-  gssize len = -1;
-
-  if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (result),
-      error))
-    goto out;
-
-  g_return_val_if_fail (g_simple_async_result_is_valid (result,
-    G_OBJECT (self), wocky_test_input_stream_read_finish), -1);
-
-  len = wocky_test_input_stream_read (stream, self->buffer, self->count, NULL,
-      error);
-
-out:
-  self->buffer = NULL;
-
-  return len;
-}
-
 static void
 read_async_complete (WockyTestInputStream *self)
 {
@@ -333,9 +319,10 @@ read_async_complete (WockyTestInputStream *self)
     {
       g_signal_handler_disconnect (self->read_cancellable,
           self->read_cancellable_sig_id);
+      g_object_unref (self->read_cancellable);
+      self->read_cancellable = NULL;
     }
 
-  self->read_cancellable = NULL;
   self->read_result = NULL;
 
   g_simple_async_result_complete_in_idle (r);
@@ -372,7 +359,7 @@ wocky_test_input_stream_read_async (GInputStream *stream,
   self->count = count;
 
   self->read_result = g_simple_async_result_new (G_OBJECT (stream),
-      callback, user_data, wocky_test_input_stream_read_finish);
+      callback, user_data, wocky_test_input_stream_read_async);
 
   if (self->read_error != NULL)
     {
@@ -382,11 +369,12 @@ wocky_test_input_stream_read_async (GInputStream *stream,
       g_error_free (self->read_error);
       self->read_error = NULL;
       read_async_complete (self);
+      return;
     }
 
   if (cancellable != NULL)
     {
-      self->read_cancellable = cancellable;
+      self->read_cancellable = g_object_ref (cancellable);
       self->read_cancellable_sig_id = g_signal_connect (cancellable,
           "cancelled", G_CALLBACK (read_cancelled_cb), self);
     }
@@ -394,6 +382,30 @@ wocky_test_input_stream_read_async (GInputStream *stream,
   wocky_test_input_stream_try_read (self);
 }
 
+static gssize
+wocky_test_input_stream_read_finish (GInputStream *stream,
+    GAsyncResult *result,
+    GError **error)
+{
+  WockyTestInputStream *self = WOCKY_TEST_INPUT_STREAM (stream);
+  gssize len = -1;
+
+  if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (result),
+      error))
+    goto out;
+
+  g_return_val_if_fail (g_simple_async_result_is_valid (result,
+    G_OBJECT (self), wocky_test_input_stream_read_async), -1);
+
+  len = wocky_test_input_stream_read (stream, self->buffer, self->count, NULL,
+      error);
+
+out:
+  self->buffer = NULL;
+
+  return len;
+}
+
 static gboolean
 wocky_test_input_stream_try_read (WockyTestInputStream *self)
 {
@@ -427,13 +439,16 @@ wocky_test_input_stream_dispose (GObject *object)
   self->dispose_has_run = TRUE;
 
   if (self->out_array != NULL)
-    g_array_free (self->out_array, TRUE);
+    g_array_unref (self->out_array);
   self->out_array = NULL;
 
   if (self->queue != NULL)
     g_async_queue_unref (self->queue);
   self->queue = NULL;
 
+  g_warn_if_fail (self->read_result == NULL);
+  g_warn_if_fail (self->read_cancellable == NULL);
+
   /* release any references held by the object here */
   if (G_OBJECT_CLASS (wocky_test_input_stream_parent_class)->dispose)
     G_OBJECT_CLASS (wocky_test_input_stream_parent_class)->dispose (object);
@@ -468,6 +483,10 @@ wocky_test_output_stream_write (GOutputStream *stream, const void *buffer,
 {
   WockyTestOutputStream *self = WOCKY_TEST_OUTPUT_STREAM (stream);
   GArray *data;
+  gsize written = count;
+
+  if (self->mode == WOCKY_TEST_STREAM_WRITE_INCOMPLETE)
+    written = MAX (count/2, 1);
 
   if (self->write_error != NULL)
     {
@@ -476,30 +495,14 @@ wocky_test_output_stream_write (GOutputStream *stream, const void *buffer,
       return -1;
     }
 
-  data = g_array_sized_new (FALSE, FALSE, sizeof (guint8), count);
+  data = g_array_sized_new (FALSE, FALSE, sizeof (guint8), written);
 
-  g_array_insert_vals (data, 0, buffer, count);
+  g_array_insert_vals (data, 0, buffer, written);
 
   g_async_queue_push (self->queue, data);
   g_signal_emit (self, output_signals[OUTPUT_DATA_WRITTEN], 0);
 
-  return count;
-}
-
-static gssize
-wocky_test_output_stream_write_finish (GOutputStream *stream,
-  GAsyncResult *result,
-  GError **error)
-{
-  if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (result),
-      error))
-    return -1;
-
-  g_return_val_if_fail (g_simple_async_result_is_valid (result,
-      G_OBJECT (stream), wocky_test_output_stream_write_finish), -1);
-
-  return g_simple_async_result_get_op_res_gssize (
-    G_SIMPLE_ASYNC_RESULT (result));
+  return written;
 }
 
 static void
@@ -519,7 +522,7 @@ wocky_test_output_stream_write_async (GOutputStream *stream,
     &error);
 
   simple = g_simple_async_result_new (G_OBJECT (stream), callback, user_data,
-    wocky_test_output_stream_write_finish);
+    wocky_test_output_stream_write_async);
 
   if (result == -1)
     {
@@ -535,6 +538,22 @@ wocky_test_output_stream_write_async (GOutputStream *stream,
   g_object_unref (simple);
 }
 
+static gssize
+wocky_test_output_stream_write_finish (GOutputStream *stream,
+  GAsyncResult *result,
+  GError **error)
+{
+  if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (result),
+      error))
+    return -1;
+
+  g_return_val_if_fail (g_simple_async_result_is_valid (result,
+      G_OBJECT (stream), wocky_test_output_stream_write_async), -1);
+
+  return g_simple_async_result_get_op_res_gssize (
+    G_SIMPLE_ASYNC_RESULT (result));
+}
+
 static void
 wocky_test_output_stream_dispose (GObject *object)
 {
@@ -618,7 +637,7 @@ wocky_test_output_stream_set_write_error (GOutputStream *stream)
 
 void
 wocky_test_stream_set_mode (GInputStream *stream,
-  WockyTestSTreamReadMode mode)
+  WockyTestStreamReadMode mode)
 {
   WOCKY_TEST_INPUT_STREAM (stream)->mode = mode;
 }
@@ -634,3 +653,21 @@ wocky_test_stream_cork (GInputStream *stream,
     wocky_test_input_stream_try_read (tstream);
 
 }
+
+void
+wocky_test_stream_set_direct_read_callback (GInputStream *stream,
+  WockyTestStreamDirectReadCb cb,
+  gpointer user_data)
+{
+  WockyTestInputStream *tstream = WOCKY_TEST_INPUT_STREAM (stream);
+
+  tstream->direct_read_cb = cb;
+  tstream->direct_read_user_data = user_data;
+}
+
+void
+wocky_test_stream_set_write_mode (GOutputStream *stream,
+  WockyTestStreamWriteMode mode)
+{
+  WOCKY_TEST_OUTPUT_STREAM (stream)->mode = mode;
+}
