@@ -1,11 +1,14 @@
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <stdio.h>
 #include <unistd.h>
 #include <string.h>
 
 #include <glib.h>
 
-#include <wocky/wocky-xmpp-connection.h>
-#include <wocky/wocky-stanza.h>
+#include <wocky/wocky.h>
 #include "wocky-test-stream.h"
 #include "wocky-test-helper.h"
 
