@@ -17,12 +17,16 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
+#if !defined (WOCKY_H_INSIDE) && !defined (WOCKY_COMPILATION)
+# error "Only <wocky/wocky.h> can be included directly."
+#endif
 
 #ifndef WOCKY_DATA_FORM_H
 #define WOCKY_DATA_FORM_H
 
 #include <glib-object.h>
 
+#include "wocky-enumtypes.h"
 #include "wocky-node.h"
 
 G_BEGIN_DECLS
@@ -84,6 +88,14 @@ struct _WockyDataFormFieldOption
  * @desc: the description of the field
  * @required: %TRUE if the field is required, otherwise %FALSE
  * @default_value: the default of the field
+ * @raw_value_contents: a %NULL-terminated array holding the literal value(s) as
+ *  specified in the original XML. For example, this might be something like
+ *  <code language="c">{ "1", NULL }</code>
+ *  or
+ *  <code language="c">{ "false", NULL }</code>
+ *  for a #WOCKY_DATA_FORM_FIELD_TYPE_BOOLEAN field, or
+ *  <code language="c">{ "hi", "there", NULL }</code>
+ *  for a #WOCKY_DATA_FORM_FIELD_TYPE_TEXT_MULTI field.
  * @value: the field value
  * @options: a #GSList of #WockyDataFormFieldOption<!-- -->s if @type
  *   if %WOCKY_DATA_FORM_FIELD_TYPE_LIST_MULTI or
@@ -100,6 +112,7 @@ struct _WockyDataFormField
   gchar *desc;
   gboolean required;
   GValue *default_value;
+  gchar **raw_value_contents;
   GValue *value;
   /* for LIST_MULTI and LIST_SINGLE only.
    * List of (WockyDataFormFieldOption *)*/
@@ -190,6 +203,9 @@ GType wocky_data_form_get_type (void);
 WockyDataForm * wocky_data_form_new_from_form (WockyNode *node,
     GError **error);
 
+WockyDataForm * wocky_data_form_new_from_node (WockyNode *x,
+    GError **error);
+
 gboolean wocky_data_form_set_type (WockyDataForm *self,
     const gchar *form_type);
 
@@ -219,6 +235,11 @@ const gchar *wocky_data_form_get_title (WockyDataForm *self);
 
 const gchar *wocky_data_form_get_instructions (WockyDataForm *self);
 
+gint wocky_data_form_field_cmp (const WockyDataFormField *left,
+    const WockyDataFormField *right);
+
+void wocky_data_form_add_to_node (WockyDataForm *self, WockyNode *node);
+
 G_END_DECLS
 
 #endif /* WOCKY_DATA_FORM_H */
