@@ -16,6 +16,9 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
+#if !defined (WOCKY_H_INSIDE) && !defined (WOCKY_COMPILATION)
+# error "Only <wocky/wocky.h> can be included directly."
+#endif
 
 #ifndef __WOCKY_PUBSUB_NODE_H__
 #define __WOCKY_PUBSUB_NODE_H__
@@ -23,6 +26,7 @@
 #include <glib-object.h>
 #include <gio/gio.h>
 
+#include "wocky-enumtypes.h"
 #include "wocky-types.h"
 #include "wocky-session.h"
 #include "wocky-pubsub-service.h"
@@ -166,7 +170,7 @@ gboolean wocky_pubsub_node_list_affiliates_finish (
 
 void wocky_pubsub_node_modify_affiliates_async (
     WockyPubsubNode *self,
-    const GList *affiliates,
+    GList *affiliates,
     GCancellable *cancellable,
     GAsyncReadyCallback callback,
     gpointer user_data);
