@@ -26,7 +26,7 @@
 #include <glib-object.h>
 #include <gio/gio.h>
 
-#include "wocky-pubsub-service-enumtypes.h"
+#include "wocky-enumtypes.h"
 #include "wocky-stanza.h"
 #include "wocky-session.h"
 #include "wocky-types.h"
