@@ -292,8 +292,8 @@ auth_failed (WockySaslAuth *sasl, gint code, const gchar *format, ...)
 static gboolean
 stream_error (WockySaslAuth *sasl, WockyStanza *stanza)
 {
-  WockyStanzaType type = WOCKY_STANZA_TYPE_NONE;
   WockySaslAuthPrivate *priv = sasl->priv;
+  GError *error = NULL;
 
   if (stanza == NULL)
     {
@@ -301,13 +301,8 @@ stream_error (WockySaslAuth *sasl, WockyStanza *stanza)
       return TRUE;
     }
 
-  wocky_stanza_get_type_info (stanza, &type, NULL);
-
-  if (type == WOCKY_STANZA_TYPE_STREAM_ERROR)
+  if (wocky_stanza_extract_stream_error (stanza, &error))
     {
-      GError *error = wocky_xmpp_stream_error_from_node (
-          wocky_stanza_get_top_node (stanza));
-
       auth_failed (sasl, WOCKY_AUTH_ERROR_STREAM, "%s: %s",
           wocky_enum_to_nick (WOCKY_TYPE_XMPP_STREAM_ERROR, error->code),
           error->message);
