@@ -22,11 +22,12 @@
 
 #include <dbus/dbus-glib.h>
 #include <dbus/dbus-glib-lowlevel.h>
-#include <telepathy-glib/interfaces.h>
+
+#include <telepathy-glib/telepathy-glib.h>
+#include <telepathy-glib/telepathy-glib-dbus.h>
 
 #define DEBUG_FLAG GABBLE_DEBUG_BYTESTREAM
 
-#include "base64.h"
 #include "bytestream-factory.h"
 #include "bytestream-iface.h"
 #include "connection.h"
@@ -100,16 +101,12 @@ gabble_bytestream_multiple_dispose (GObject *object)
   GabbleBytestreamMultiple *self = GABBLE_BYTESTREAM_MULTIPLE (object);
   GabbleBytestreamMultiplePrivate *priv =
       GABBLE_BYTESTREAM_MULTIPLE_GET_PRIVATE (self);
-  TpHandleRepoIface *contact_repo = tp_base_connection_get_handles (
-      (TpBaseConnection *) priv->conn, TP_HANDLE_TYPE_CONTACT);
 
   if (priv->dispose_has_run)
     return;
 
   priv->dispose_has_run = TRUE;
 
-  tp_handle_unref (contact_repo, priv->peer_handle);
-
   if (priv->state != GABBLE_BYTESTREAM_STATE_CLOSED)
     {
       gabble_bytestream_iface_close (GABBLE_BYTESTREAM_IFACE (self), NULL);
@@ -263,8 +260,6 @@ gabble_bytestream_multiple_constructor (GType type,
   contact_repo = tp_base_connection_get_handles (
       (TpBaseConnection *) priv->conn, TP_HANDLE_TYPE_CONTACT);
 
-  tp_handle_ref (contact_repo, priv->peer_handle);
-
   jid = tp_handle_inspect (contact_repo, priv->peer_handle);
 
   if (priv->peer_resource != NULL)
