@@ -24,11 +24,8 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include <telepathy-glib/interfaces.h>
-#include <telepathy-glib/channel-manager.h>
-#include <telepathy-glib/handle-repo.h>
-#include <telepathy-glib/handle-repo-dynamic.h>
-#include <telepathy-glib/util.h>
+#include <telepathy-glib/telepathy-glib.h>
+#include <telepathy-glib/telepathy-glib-dbus.h>
 
 #define DEBUG_FLAG GABBLE_DEBUG_PRESENCE
 #include "debug.h"
@@ -64,6 +61,8 @@ static const Feature self_advertised_features[] =
   { FEATURE_FIXED, NS_TUBES },
   { FEATURE_FIXED, NS_BYTESTREAMS },
   { FEATURE_FIXED, NS_VERSION },
+  { FEATURE_FIXED, NS_LAST },
+  { FEATURE_FIXED, NS_RECEIPTS },
 
 #ifdef ENABLE_FILE_TRANSFER
   { FEATURE_OPTIONAL, NS_FILE_TRANSFER },
@@ -453,7 +452,7 @@ void
 gabble_capability_set_update (GabbleCapabilitySet *target,
     const GabbleCapabilitySet *source)
 {
-  TpIntSet *ret;
+  TpIntset *ret;
   g_return_if_fail (target != NULL);
   g_return_if_fail (source != NULL);
 
@@ -539,9 +538,7 @@ gabble_capability_set_add (GabbleCapabilitySet *caps,
   g_return_if_fail (cap != NULL);
 
   handle = tp_handle_ensure (feature_handles, cap, NULL, NULL);
-
   tp_handle_set_add (caps->handles, handle);
-  tp_handle_unref (feature_handles, handle);
 }
 
 gboolean
@@ -613,16 +610,17 @@ gboolean
 gabble_capability_set_has_one (const GabbleCapabilitySet *caps,
     const GabbleCapabilitySet *alternatives)
 {
-  TpIntSetIter iter;
+  TpIntsetFastIter iter;
+  guint element;
 
   g_return_val_if_fail (caps != NULL, FALSE);
   g_return_val_if_fail (alternatives != NULL, FALSE);
 
-  tp_intset_iter_init (&iter, tp_handle_set_peek (alternatives->handles));
+  tp_intset_fast_iter_init (&iter, tp_handle_set_peek (alternatives->handles));
 
-  while (tp_intset_iter_next (&iter))
+  while (tp_intset_fast_iter_next (&iter, &element))
     {
-      if (tp_handle_set_is_member (caps->handles, iter.element))
+      if (tp_handle_set_is_member (caps->handles, element))
         {
           return TRUE;
         }
@@ -636,16 +634,17 @@ gboolean
 gabble_capability_set_at_least (const GabbleCapabilitySet *caps,
     const GabbleCapabilitySet *query)
 {
-  TpIntSetIter iter;
+  TpIntsetFastIter iter;
+  guint element;
 
   g_return_val_if_fail (caps != NULL, FALSE);
   g_return_val_if_fail (query != NULL, FALSE);
 
-  tp_intset_iter_init (&iter, tp_handle_set_peek (query->handles));
+  tp_intset_fast_iter_init (&iter, tp_handle_set_peek (query->handles));
 
-  while (tp_intset_iter_next (&iter))
+  while (tp_intset_fast_iter_next (&iter, &element))
     {
-      if (!tp_handle_set_is_member (caps->handles, iter.element))
+      if (!tp_handle_set_is_member (caps->handles, element))
         {
           return FALSE;
         }
@@ -670,16 +669,17 @@ void
 gabble_capability_set_foreach (const GabbleCapabilitySet *caps,
     GFunc func, gpointer user_data)
 {
-  TpIntSetIter iter;
+  TpIntsetFastIter iter;
+  guint element;
 
   g_return_if_fail (caps != NULL);
   g_return_if_fail (func != NULL);
 
-  tp_intset_iter_init (&iter, tp_handle_set_peek (caps->handles));
+  tp_intset_fast_iter_init (&iter, tp_handle_set_peek (caps->handles));
 
-  while (tp_intset_iter_next (&iter))
+  while (tp_intset_fast_iter_next (&iter, &element))
     {
-      const gchar *var = tp_handle_inspect (feature_handles, iter.element);
+      const gchar *var = tp_handle_inspect (feature_handles, element);
 
       g_return_if_fail (var != NULL);
 
@@ -690,10 +690,10 @@ gabble_capability_set_foreach (const GabbleCapabilitySet *caps,
 
 static void
 append_intset (GString *ret,
-    const TpIntSet *cap_ints,
+    const TpIntset *cap_ints,
     const gchar *indent)
 {
-  TpIntSetFastIter iter;
+  TpIntsetFastIter iter;
   guint element;
 
   tp_intset_fast_iter_init (&iter, cap_ints);
@@ -739,7 +739,7 @@ gabble_capability_set_dump_diff (const GabbleCapabilitySet *old_caps,
     const GabbleCapabilitySet *new_caps,
     const gchar *indent)
 {
-  TpIntSet *old_ints, *new_ints, *rem, *add;
+  TpIntset *old_ints, *new_ints, *rem, *add;
   GString *ret;
 
   g_return_val_if_fail (old_caps != NULL, NULL);
