@@ -22,7 +22,8 @@
 #include <string.h>
 #include <stdlib.h>
 
-#include <telepathy-glib/interfaces.h>
+#include <telepathy-glib/telepathy-glib.h>
+#include <telepathy-glib/telepathy-glib-dbus.h>
 
 #include <extensions/extensions.h>
 
