@@ -25,7 +25,7 @@
 #define __GABBLE_DISCO_H__
 
 #include <glib-object.h>
-#include <loudmouth/loudmouth.h>
+#include <wocky/wocky.h>
 
 #include "types.h"
 
@@ -83,7 +83,7 @@ struct _GabbleDisco {
 };
 
 typedef void (*GabbleDiscoCb)(GabbleDisco *self, GabbleDiscoRequest *request,
-    const gchar *jid, const gchar *node, LmMessageNode *query_result,
+    const gchar *jid, const gchar *node, WockyNode *query_result,
     GError* error, gpointer user_data);
 
 GabbleDisco *gabble_disco_new (GabbleConnection *);
