@@ -27,12 +27,6 @@ G_BEGIN_DECLS
 
 int gabble_main (int argc, char **argv);
 
-#ifdef ENABLE_DEBUG
-void gabble_lm_debug (void);
-#else
-#define gabble_lm_debug() G_STMT_START { } G_STMT_END
-#endif
-
 /* To be used only by tests */
 void gabble_init (void);
 
