@@ -22,10 +22,10 @@
 
 #include <glib-object.h>
 
-#include <telepathy-glib/base-connection.h>
+#include <telepathy-glib/telepathy-glib.h>
+
 #include "connection.h"
 #include "bytestream-iface.h"
-#include "tubes-channel.h"
 
 G_BEGIN_DECLS
 
@@ -75,6 +75,12 @@ void gabble_private_tubes_factory_handle_si_stream_request (
     GabblePrivateTubesFactory *fac, GabbleBytestreamIface *bytestream,
     TpHandle handle, const gchar *stream_id, WockyStanza *msg);
 
+gboolean gabble_private_tubes_factory_extract_tube_information (
+    TpHandleRepoIface *contact_repo, WockyNode *tube_node,
+    TpTubeType *type, TpHandle *initiator_handle,
+    const gchar **service, GHashTable **parameters,
+    guint64 *tube_id);
+
 G_END_DECLS
 
 #endif /* #ifndef __PRIVATE_TUBES_FACTORY_H__ */
