@@ -36,15 +36,8 @@
 #include <dbus/dbus-glib.h>
 #include <wocky/wocky.h>
 
-#include <telepathy-glib/channel-iface.h>
-#include <telepathy-glib/dbus.h>
-#include <telepathy-glib/enums.h>
-#include <telepathy-glib/errors.h>
-#include <telepathy-glib/exportable-channel.h>
-#include <telepathy-glib/gtypes.h>
-#include <telepathy-glib/interfaces.h>
-#include <telepathy-glib/svc-channel.h>
-#include <telepathy-glib/svc-generic.h>
+#include <telepathy-glib/telepathy-glib.h>
+#include <telepathy-glib/telepathy-glib-dbus.h>
 
 #define DEBUG_FLAG GABBLE_DEBUG_AUTH
 
@@ -66,12 +59,6 @@ G_DEFINE_TYPE_WITH_CODE (GabbleServerSaslChannel, gabble_server_sasl_channel,
         TP_TYPE_SVC_CHANNEL_INTERFACE_SASL_AUTHENTICATION,
         sasl_auth_iface_init));
 
-static const gchar *gabble_server_sasl_channel_interfaces[] = {
-  TP_IFACE_CHANNEL_INTERFACE_SASL_AUTHENTICATION,
-  TP_IFACE_CHANNEL_INTERFACE_SECURABLE,
-  NULL
-};
-
 enum
 {
   /* server authentication channel */
@@ -106,10 +93,25 @@ struct _GabbleServerSaslChannelPrivate
   GHashTable *sasl_error_details;
   /* Given to the Connection on request */
   TpConnectionStatusReason disconnect_reason;
+  GError *wocky_auth_error /* = NULL */;
 
   GSimpleAsyncResult *result;
 };
 
+static GPtrArray *
+gabble_server_sasl_channel_get_interfaces (TpBaseChannel *base)
+{
+  GPtrArray *interfaces;
+
+  interfaces = TP_BASE_CHANNEL_CLASS (
+      gabble_server_sasl_channel_parent_class)->get_interfaces (base);
+
+  g_ptr_array_add (interfaces, TP_IFACE_CHANNEL_INTERFACE_SASL_AUTHENTICATION);
+  g_ptr_array_add (interfaces, TP_IFACE_CHANNEL_INTERFACE_SECURABLE);
+
+  return interfaces;
+}
+
 static void
 gabble_server_sasl_channel_init (GabbleServerSaslChannel *self)
 {
@@ -274,6 +276,7 @@ gabble_server_sasl_channel_finalize (GObject *object)
 
   g_free (priv->sasl_error);
   g_hash_table_unref (priv->sasl_error_details);
+  g_clear_error (&priv->wocky_auth_error);
 
   if (G_OBJECT_CLASS (gabble_server_sasl_channel_parent_class)->finalize)
     G_OBJECT_CLASS (gabble_server_sasl_channel_parent_class)->finalize (object);
@@ -337,7 +340,7 @@ gabble_server_sasl_channel_class_init (GabbleServerSaslChannelClass *klass)
 
   channel_class->channel_type =
     TP_IFACE_CHANNEL_TYPE_SERVER_AUTHENTICATION;
-  channel_class->interfaces = gabble_server_sasl_channel_interfaces;
+  channel_class->get_interfaces = gabble_server_sasl_channel_get_interfaces;
   channel_class->target_handle_type = TP_HANDLE_TYPE_NONE;
   channel_class->fill_immutable_properties =
     gabble_server_sasl_channel_fill_immutable_properties;
@@ -431,13 +434,12 @@ gabble_server_sasl_channel_class_init (GabbleServerSaslChannelClass *klass)
 }
 
 static void
-change_current_state (GabbleServerSaslChannel *self,
-    TpSASLStatus status,
+set_errors (
+    GabbleServerSaslChannel *self,
     const gchar *dbus_error,
-    const gchar *debug_message)
+    const gchar *debug_message,
+    const GError *error)
 {
-  self->priv->sasl_status = status;
-
   g_free (self->priv->sasl_error);
   self->priv->sasl_error = g_strdup (dbus_error);
 
@@ -446,12 +448,41 @@ change_current_state (GabbleServerSaslChannel *self,
     tp_asv_set_string (self->priv->sasl_error_details, "debug-message",
         debug_message);
 
+  g_clear_error (&self->priv->wocky_auth_error);
+  self->priv->wocky_auth_error = g_error_copy (error);
+}
+
+static void
+change_current_state (GabbleServerSaslChannel *self,
+    TpSASLStatus status)
+{
+  self->priv->sasl_status = status;
+
   tp_svc_channel_interface_sasl_authentication_emit_sasl_status_changed (
       self, self->priv->sasl_status,
       self->priv->sasl_error,
       self->priv->sasl_error_details);
 }
 
+static void
+complete_operation (
+    GabbleServerSaslChannel *self,
+    gboolean in_idle)
+{
+  GabbleServerSaslChannelPrivate *priv = self->priv;
+  GSimpleAsyncResult *r = priv->result;
+
+  g_return_if_fail (priv->result != NULL);
+  priv->result = NULL;
+
+  if (in_idle)
+    g_simple_async_result_complete_in_idle (r);
+  else
+    g_simple_async_result_complete (r);
+
+  g_object_unref (r);
+}
+
 /**
  * SASL Authentication Channel Interface
  */
@@ -470,7 +501,7 @@ gabble_server_sasl_channel_raise (DBusGMethodInvocation *context,
   GError *error = NULL;
 
   va_start (ap, message);
-  error = g_error_new_valist (TP_ERRORS, code, message, ap);
+  error = g_error_new_valist (TP_ERROR, code, message, ap);
   va_end (ap);
 
   dbus_g_method_return_error (context, error);
@@ -489,7 +520,6 @@ gabble_server_sasl_channel_start_mechanism_with_data (
   GabbleServerSaslChannel *self = GABBLE_SERVER_SASL_CHANNEL (iface);
   GabbleServerSaslChannelPrivate *priv = self->priv;
   WockyAuthRegistryStartData *start_data;
-  GSimpleAsyncResult *r = priv->result;
   GString *initial_data = NULL;
 
   if (self->priv->sasl_status != TP_SASL_STATUS_NOT_STARTED)
@@ -503,15 +533,13 @@ gabble_server_sasl_channel_start_mechanism_with_data (
 
   /* NotStarted state is entered by creating the channel: the caller must
    * call start_auth_async immediately */
-  g_assert (r != NULL);
-  g_assert (g_simple_async_result_is_valid (G_ASYNC_RESULT (r),
+  g_assert (priv->result != NULL);
+  g_assert (g_simple_async_result_is_valid (G_ASYNC_RESULT (priv->result),
         G_OBJECT (self), gabble_server_sasl_channel_start_auth_async));
 
   if (tp_strv_contains ((const gchar * const *) priv->available_mechanisms,
         in_Mechanism))
     {
-      priv->result = NULL;
-
       if (in_InitialData != NULL)
         {
           /* The initial data might be secret (for PLAIN etc.), and also might
@@ -527,16 +555,15 @@ gabble_server_sasl_channel_start_mechanism_with_data (
               in_Mechanism);
         }
 
-      change_current_state (self, TP_SASL_STATUS_IN_PROGRESS, NULL, NULL);
+      change_current_state (self, TP_SASL_STATUS_IN_PROGRESS);
       dbus_g_method_return (context);
 
       start_data =
         wocky_auth_registry_start_data_new (in_Mechanism, initial_data);
 
-      g_simple_async_result_set_op_res_gpointer (r,
+      g_simple_async_result_set_op_res_gpointer (priv->result,
           start_data, (GDestroyNotify) wocky_auth_registry_start_data_free);
-      g_simple_async_result_complete_in_idle (r);
-      g_object_unref (r);
+      complete_operation (self, TRUE);
 
       if (initial_data != NULL)
         g_string_free (initial_data, TRUE);
@@ -567,8 +594,8 @@ gabble_server_sasl_channel_respond (
 {
   GabbleServerSaslChannel *self =
     GABBLE_SERVER_SASL_CHANNEL (channel);
+  GabbleServerSaslChannelPrivate *priv = self->priv;
   GString *response_data;
-  GSimpleAsyncResult *r = self->priv->result;
 
   if (self->priv->sasl_status != TP_SASL_STATUS_IN_PROGRESS)
     {
@@ -580,7 +607,7 @@ gabble_server_sasl_channel_respond (
       return;
     }
 
-  if (r == NULL)
+  if (priv->result == NULL)
     {
       gabble_server_sasl_channel_raise (context, TP_ERROR_NOT_AVAILABLE,
           "You already responded to the most recent challenge");
@@ -588,26 +615,22 @@ gabble_server_sasl_channel_respond (
       return;
     }
 
-  g_assert (g_simple_async_result_is_valid (G_ASYNC_RESULT (r),
+  g_assert (g_simple_async_result_is_valid (G_ASYNC_RESULT (priv->result),
         G_OBJECT (self), gabble_server_sasl_channel_challenge_async));
 
   /* The response might be secret (for PLAIN etc.), and also might
    * not be UTF-8 or even text, so we just output the length */
   DEBUG ("responding with %u bytes", in_Response_Data->len);
 
-  self->priv->result = NULL;
-
   if (in_Response_Data->len > 0)
     response_data = g_string_new_len (in_Response_Data->data,
         in_Response_Data->len);
   else
     response_data = NULL;
 
-  g_simple_async_result_set_op_res_gpointer (r, response_data,
+  g_simple_async_result_set_op_res_gpointer (priv->result, response_data,
       (GDestroyNotify) wocky_g_string_free);
-
-  g_simple_async_result_complete_in_idle (r);
-  g_object_unref (r);
+  complete_operation (self, TRUE);
 
   tp_svc_channel_interface_sasl_authentication_return_from_respond (
       context);
@@ -619,10 +642,9 @@ gabble_server_sasl_channel_accept_sasl (
     DBusGMethodInvocation *context)
 {
   GabbleServerSaslChannel *self = GABBLE_SERVER_SASL_CHANNEL (channel);
-  GSimpleAsyncResult *r = self->priv->result;
+  GabbleServerSaslChannelPrivate *priv = self->priv;
   const gchar *message = NULL;
 
-
   switch (self->priv->sasl_status)
     {
     case TP_SASL_STATUS_NOT_STARTED:
@@ -633,7 +655,7 @@ gabble_server_sasl_channel_accept_sasl (
       /* In this state, the only valid time to call this method is in response
        * to a challenge, to indicate that, actually, that challenge was
        * additional data for a successful authentication. */
-      if (r == NULL)
+      if (priv->result == NULL)
         {
           message = "In_Progress, but you already responded to the last "
             "challenge";
@@ -642,10 +664,9 @@ gabble_server_sasl_channel_accept_sasl (
         {
           DEBUG ("client says the last challenge was actually final data "
               "and has accepted it");
-          g_assert (g_simple_async_result_is_valid (G_ASYNC_RESULT (r),
+          g_assert (g_simple_async_result_is_valid (G_ASYNC_RESULT (priv->result),
                 G_OBJECT (self), gabble_server_sasl_channel_challenge_async));
-          change_current_state (self, TP_SASL_STATUS_CLIENT_ACCEPTED, NULL,
-              NULL);
+          change_current_state (self, TP_SASL_STATUS_CLIENT_ACCEPTED);
         }
       break;
 
@@ -654,9 +675,9 @@ gabble_server_sasl_channel_accept_sasl (
        * success_async(), i.e. waiting for the UI to check whether it's
        * happy too. AcceptSASL means that it is. */
       DEBUG ("client has accepted server's success");
-      g_assert (g_simple_async_result_is_valid (G_ASYNC_RESULT (r),
+      g_assert (g_simple_async_result_is_valid (G_ASYNC_RESULT (priv->result),
             G_OBJECT (self), gabble_server_sasl_channel_success_async));
-      change_current_state (self, TP_SASL_STATUS_SUCCEEDED, NULL, NULL);
+      change_current_state (self, TP_SASL_STATUS_SUCCEEDED);
       break;
 
     case TP_SASL_STATUS_CLIENT_ACCEPTED:
@@ -687,20 +708,18 @@ gabble_server_sasl_channel_accept_sasl (
       return;
     }
 
-  if (r != NULL)
+  if (priv->result != NULL)
     {
       /* This is a bit weird - this code is run for two different async
        * results. In the In_Progress case, this code results in
        * success with the GSimpleAsyncResult's op_res left as NULL, which
        * is what Wocky wants for an empty response. In the Server_Succeeded
        * response, the async result is just success or error - we succeed. */
-      self->priv->result = NULL;
 
       /* We want want to complete not in an idle because if we do we
        * will hit fd.o#32278. This is safe because we're being called
        * from dbus-glib in the main loop. */
-      g_simple_async_result_complete (r);
-      g_object_unref (r);
+      complete_operation (self, FALSE);
     }
 
   tp_svc_channel_interface_sasl_authentication_return_from_accept_sasl (
@@ -715,8 +734,7 @@ gabble_server_sasl_channel_abort_sasl (
     DBusGMethodInvocation *context)
 {
   GabbleServerSaslChannel *self = GABBLE_SERVER_SASL_CHANNEL (channel);
-  GSimpleAsyncResult *r = self->priv->result;
-  guint code;
+  GabbleServerSaslChannelPrivate *priv = self->priv;
   const gchar *dbus_error;
 
   switch (self->priv->sasl_status)
@@ -736,49 +754,53 @@ gabble_server_sasl_channel_abort_sasl (
       case TP_SASL_STATUS_NOT_STARTED:
       case TP_SASL_STATUS_IN_PROGRESS:
       case TP_SASL_STATUS_SERVER_SUCCEEDED:
+      {
+        GError *error = NULL;
+
         switch (in_Reason)
           {
             case TP_SASL_ABORT_REASON_INVALID_CHALLENGE:
-              DEBUG ("invalid challenge (%s)", in_Debug_Message);
-              code = WOCKY_AUTH_ERROR_INVALID_REPLY;
+              g_set_error (&error, WOCKY_AUTH_ERROR,
+                  WOCKY_AUTH_ERROR_INVALID_REPLY,
+                  "invalid challenge (%s)", in_Debug_Message);
               dbus_error = TP_ERROR_STR_SERVICE_CONFUSED;
               break;
 
             case TP_SASL_ABORT_REASON_USER_ABORT:
-              DEBUG ("user aborted auth (%s)", in_Debug_Message);
-              code = WOCKY_AUTH_ERROR_FAILURE;
+              g_set_error (&error, WOCKY_AUTH_ERROR,
+                  WOCKY_AUTH_ERROR_FAILURE,
+                  "user aborted auth (%s)", in_Debug_Message);
               dbus_error = TP_ERROR_STR_CANCELLED;
               break;
 
             default:
-              DEBUG ("unknown reason code %u, treating as User_Abort (%s)",
+              g_set_error (&error, WOCKY_AUTH_ERROR,
+                  WOCKY_AUTH_ERROR_FAILURE,
+                  "unknown reason code %u, treating as User_Abort (%s)",
                   in_Reason, in_Debug_Message);
-              code = WOCKY_AUTH_ERROR_FAILURE;
               dbus_error = TP_ERROR_STR_CANCELLED;
               break;
           }
 
-        if (r != NULL)
-          {
-            self->priv->result = NULL;
+        DEBUG ("%s", error->message);
 
+        set_errors (self, dbus_error, in_Debug_Message, error);
+        change_current_state (self, TP_SASL_STATUS_CLIENT_FAILED);
+
+        if (priv->result != NULL)
+          {
             /* If Not_Started, we're returning failure from start_auth_async.
              * If In_Progress, we might be returning failure from
              *  challenge_async, if one is outstanding.
              * If Server_Succeeded, we're returning failure from success_async.
              */
-
-            g_simple_async_result_set_error (r, WOCKY_AUTH_ERROR, code,
-                "Authentication aborted: %s", in_Debug_Message);
-
-            g_simple_async_result_complete_in_idle (r);
-            g_object_unref (r);
+            g_simple_async_result_set_from_error (priv->result, error);
+            complete_operation (self, TRUE);
           }
 
-        change_current_state (self, TP_SASL_STATUS_CLIENT_FAILED,
-            dbus_error, in_Debug_Message);
+        g_error_free (error);
         break;
-
+      }
       default:
         g_assert_not_reached ();
     }
@@ -840,7 +862,7 @@ gabble_server_sasl_channel_challenge_async (GabbleServerSaslChannel *self,
 
   g_assert (!tp_base_channel_is_destroyed ((TpBaseChannel *) self));
   g_assert (priv->result == NULL);
-  g_assert (priv->sasl_status == TP_SASL_STATUS_IN_PROGRESS);
+
   /* it might be sensitive, and also might not be UTF-8 text, so just print
    * the length */
   DEBUG ("New challenge, %" G_GSIZE_FORMAT " bytes", challenge_data->len);
@@ -848,13 +870,26 @@ gabble_server_sasl_channel_challenge_async (GabbleServerSaslChannel *self,
   priv->result = g_simple_async_result_new (G_OBJECT (self), callback,
       user_data, gabble_server_sasl_channel_challenge_async);
 
-  challenge_ay = g_array_sized_new (FALSE, FALSE, sizeof (gchar),
-      challenge_data->len);
-  g_array_append_vals (challenge_ay, challenge_data->str,
-      challenge_data->len);
+  switch (priv->sasl_status)
+    {
+      case TP_SASL_STATUS_IN_PROGRESS:
+        challenge_ay = g_array_sized_new (FALSE, FALSE, sizeof (gchar),
+            challenge_data->len);
+        g_array_append_vals (challenge_ay, challenge_data->str,
+            challenge_data->len);
 
-  tp_svc_channel_interface_sasl_authentication_emit_new_challenge (
-      self, challenge_ay);
+        tp_svc_channel_interface_sasl_authentication_emit_new_challenge (
+            self, challenge_ay);
+        break;
+      case TP_SASL_STATUS_CLIENT_FAILED:
+        g_return_if_fail (priv->wocky_auth_error != NULL);
+        g_simple_async_result_set_from_error (priv->result,
+            priv->wocky_auth_error);
+        complete_operation (self, TRUE);
+        return;
+      default:
+        g_assert_not_reached ();
+    }
 }
 
 gboolean
@@ -874,12 +909,11 @@ gabble_server_sasl_channel_success_async (GabbleServerSaslChannel *self,
     gpointer user_data)
 {
   GabbleServerSaslChannelPrivate *priv = self->priv;
-  GSimpleAsyncResult *r;
 
   g_assert (!tp_base_channel_is_destroyed ((TpBaseChannel *) self));
   g_assert (priv->result == NULL);
 
-  r = g_simple_async_result_new (G_OBJECT (self),
+  priv->result = g_simple_async_result_new (G_OBJECT (self),
       callback, user_data,
       gabble_server_sasl_channel_success_async);
 
@@ -887,16 +921,12 @@ gabble_server_sasl_channel_success_async (GabbleServerSaslChannel *self,
 
   if (self->priv->sasl_status != TP_SASL_STATUS_CLIENT_ACCEPTED)
     {
-      priv->result = r;
-      change_current_state (self, TP_SASL_STATUS_SERVER_SUCCEEDED,
-          NULL, NULL);
+      change_current_state (self, TP_SASL_STATUS_SERVER_SUCCEEDED);
     }
   else
     {
-      change_current_state (self, TP_SASL_STATUS_SUCCEEDED, NULL,
-          NULL);
-      g_simple_async_result_complete_in_idle (r);
-      g_object_unref (r);
+      change_current_state (self, TP_SASL_STATUS_SUCCEEDED);
+      complete_operation (self, TRUE);
     }
 }
 
@@ -924,11 +954,12 @@ gabble_server_sasl_channel_fail (GabbleServerSaslChannel *self,
 
   gabble_set_tp_conn_error_from_wocky (error, TP_CONNECTION_STATUS_CONNECTING,
       &conn_reason, &tp_error);
-  g_assert (tp_error->domain == TP_ERRORS);
+  g_assert (tp_error->domain == TP_ERROR);
 
   DEBUG ("auth failed: %s", tp_error->message);
-  change_current_state (self, TP_SASL_STATUS_SERVER_FAILED,
-      tp_error_get_dbus_name (tp_error->code), tp_error->message);
+  set_errors (self,
+      tp_error_get_dbus_name (tp_error->code), tp_error->message, error);
+  change_current_state (self, TP_SASL_STATUS_SERVER_FAILED);
   self->priv->disconnect_reason = conn_reason;
 }
 
@@ -961,21 +992,37 @@ gabble_server_sasl_channel_close (TpBaseChannel *channel)
 {
   GabbleServerSaslChannel *self = GABBLE_SERVER_SASL_CHANNEL (channel);
   GabbleServerSaslChannelPrivate *priv = self->priv;
+  GError error = { WOCKY_AUTH_ERROR, WOCKY_AUTH_ERROR_FAILURE,
+      "Client aborted authentication." };
 
   DEBUG ("called on %p", self);
 
+  switch (priv->sasl_status)
+    {
+    case TP_SASL_STATUS_NOT_STARTED:
+    case TP_SASL_STATUS_IN_PROGRESS:
+    case TP_SASL_STATUS_SERVER_SUCCEEDED:
+      set_errors (self, TP_ERROR_STR_AUTHENTICATION_FAILED, "Close() called",
+          &error);
+      break;
+
+    case TP_SASL_STATUS_CLIENT_ACCEPTED:
+    case TP_SASL_STATUS_SUCCEEDED:
+      /* Hooray! */
+      break;
+
+    case TP_SASL_STATUS_SERVER_FAILED:
+    case TP_SASL_STATUS_CLIENT_FAILED:
+      g_warn_if_fail (priv->sasl_error != NULL);
+      break;
+    }
+
   if (priv->result != NULL)
     {
-      GSimpleAsyncResult *r = priv->result;
-
       DEBUG ("closed channel");
 
-      priv->result = NULL;
-      g_simple_async_result_set_error (r, WOCKY_AUTH_ERROR,
-          WOCKY_AUTH_ERROR_FAILURE,
-          "%s", "Client aborted authentication.");
-      g_simple_async_result_complete_in_idle (r);
-      g_object_unref (r);
+      g_simple_async_result_set_from_error (priv->result, &error);
+      complete_operation (self, TRUE);
     }
 
   tp_base_channel_destroyed (channel);
@@ -986,6 +1033,8 @@ gabble_server_sasl_channel_close (TpBaseChannel *channel)
  * @details: (out) (transfer full) (element-type utf8 GObject.Value): the
  *  error details
  * @reason: (out): the reason with which to disconnect
+ * @error: (out): an error in a domain Wocky understands describing what went
+ *  wrong
  *
  * Returns: %TRUE if an error was copied; %FALSE leaving the 'out' parameters
  *  untouched if there is no error
@@ -994,7 +1043,8 @@ gboolean
 gabble_server_sasl_channel_get_failure_details (GabbleServerSaslChannel *self,
     gchar **dbus_error,
     GHashTable **details,
-    TpConnectionStatusReason *reason)
+    TpConnectionStatusReason *reason,
+    GError **error)
 {
   if (self->priv->sasl_error != NULL)
     {
@@ -1007,6 +1057,9 @@ gabble_server_sasl_channel_get_failure_details (GabbleServerSaslChannel *self,
       if (reason != NULL)
         *reason = self->priv->disconnect_reason;
 
+      if (error != NULL)
+        *error = g_error_copy (self->priv->wocky_auth_error);
+
       return TRUE;
     }
   else
