@@ -2,7 +2,10 @@
 #include "config.h"
 
 #include <string.h>
-#include <unistd.h>
+
+#ifdef HAVE_UNISTD_H
+# include <unistd.h>
+#endif
 
 #include <glib.h>
 
