@@ -8,10 +8,6 @@ import constants as cs
 import ns
 
 def test(q, bus, conn, stream):
-    conn.Connect()
-    q.expect('dbus-signal', signal='StatusChanged',
-            args=[cs.CONN_STATUS_CONNECTED, cs.CSR_REQUESTED])
-
     jid = 'foo@bar.com'
 
     iq = elem_iq(stream, 'get', from_=jid)(elem(ns.DISCO_INFO, 'query'))
