@@ -12,6 +12,12 @@ from caps_helper import compute_caps_hash, send_disco_reply
 import constants as cs
 import ns
 
+from config import VOIP_ENABLED
+
+if not VOIP_ENABLED:
+    print "NOTE: built with --disable-voip"
+    raise SystemExit(77)
+
 def test(q, bus, conn, stream):
     client = 'http://example.com/perverse-client'
     contact_bare_jid = 'edgecase@example.com'
