@@ -2,6 +2,12 @@
 import constants as cs
 from file_transfer_helper import exec_file_transfer_test, ReceiveFileTest
 
+from config import FILE_TRANSFER_ENABLED
+
+if not FILE_TRANSFER_ENABLED:
+    print "NOTE: built with --disable-file-transfer"
+    raise SystemExit(77)
+
 class ReceiveFileAndCancelWhileReceiving(ReceiveFileTest):
     def receive_file(self):
         # Connect to Gabble's socket
