@@ -5,6 +5,12 @@ from file_transfer_helper import SendFileTest, exec_file_transfer_test
 from twisted.words.xish import domish
 import ns
 
+from config import FILE_TRANSFER_ENABLED
+
+if not FILE_TRANSFER_ENABLED:
+    print "NOTE: built with --disable-file-transfer"
+    raise SystemExit(77)
+
 class SendFileDeclinedTest(SendFileTest):
     def got_send_iq(self):
         SendFileTest.got_send_iq(self)
