@@ -7,6 +7,10 @@ if not JINGLE_FILE_TRANSFER_ENABLED:
     print "NOTE: built with --disable-file-transfer or --disable-voip"
     raise SystemExit(77)
 
+print("FIXME: test is not stable enough.\n" +
+      "    https://bugs.freedesktop.org/show_bug.cgi?id=49595")
+raise SystemExit(77)
+
 class SendFileBeforeAccept(SendFileTest):
     def __init__(self, file, address_type,
                  access_control, acces_control_param):
