@@ -10,6 +10,12 @@ from jingletest2 import JingleTest2, test_all_dialects
 
 import constants as cs
 
+from config import VOIP_ENABLED
+
+if not VOIP_ENABLED:
+    print "NOTE: built with --disable-voip"
+    raise SystemExit(77)
+
 def test_busy(jp, q, bus, conn, stream):
     test(jp, q, bus, conn, stream, True)
 
