@@ -12,9 +12,8 @@ import dbus
 import re
 
 def test(q, bus, conn, stream):
-    conn.Connect()
-    q.expect('dbus-signal', signal='StatusChanged',
-        args=[cs.CONN_STATUS_CONNECTED, cs.CSR_REQUESTED])
+    # Wait for us to be fully logged in
+    q.expect('stream-presence')
 
     test_create_pmuc(q, conn, stream)
     test_create_pmuc_with_invitee(q, conn, stream)
