@@ -10,14 +10,8 @@ from servicetest import call_async, EventPattern, tp_name_prefix
 import constants as cs
 
 def test(q, bus, conn, stream):
-    conn.Connect()
-
-    _, event = q.expect_many(
-            EventPattern('dbus-signal', signal='StatusChanged',
-                args=[cs.CONN_STATUS_CONNECTED, cs.CSR_REQUESTED]),
-            EventPattern('stream-iq', to='localhost',
-                query_ns='http://jabber.org/protocol/disco#items'),
-            )
+    event = q.expect('stream-iq', to='localhost',
+                query_ns='http://jabber.org/protocol/disco#items')
 
     result = make_result_iq(stream, event.stanza)
     item = result.firstChildElement().addElement('item')
