@@ -2,6 +2,7 @@ AMP = "http://jabber.org/protocol/amp"
 BYTESTREAMS = 'http://jabber.org/protocol/bytestreams'
 CHAT_STATES = 'http://jabber.org/protocol/chatstates'
 CAPS = "http://jabber.org/protocol/caps"
+CLIENT = "jabber:client"
 DISCO_INFO = "http://jabber.org/protocol/disco#info"
 DISCO_ITEMS = "http://jabber.org/protocol/disco#items"
 FEATURE_NEG = 'http://jabber.org/protocol/feature-neg'
@@ -25,6 +26,7 @@ JINGLE_015 = "http://jabber.org/protocol/jingle"
 JINGLE_015_AUDIO = "http://jabber.org/protocol/jingle/description/audio"
 JINGLE_015_VIDEO = "http://jabber.org/protocol/jingle/description/video"
 JINGLE = "urn:xmpp:jingle:1"
+JINGLE_ERRORS = "urn:xmpp:jingle:errors:1"
 JINGLE_RTP = "urn:xmpp:jingle:apps:rtp:1"
 JINGLE_RTP_AUDIO = "urn:xmpp:jingle:apps:rtp:audio"
 JINGLE_RTP_VIDEO = "urn:xmpp:jingle:apps:rtp:video"
@@ -55,6 +57,7 @@ OLPC_CURRENT_ACTIVITY = "http://laptop.org/xmpp/current-activity"
 OLPC_CURRENT_ACTIVITY_NOTIFY = "%s+notify" % OLPC_CURRENT_ACTIVITY
 PUBSUB = "http://jabber.org/protocol/pubsub"
 PUBSUB_EVENT = "%s#event" % PUBSUB
+RECEIPTS = "urn:xmpp:receipts"
 REGISTER = "jabber:iq:register"
 ROSTER = "jabber:iq:roster"
 SEARCH = 'jabber:iq:search'
