@@ -12,11 +12,6 @@ import constants as cs
 import ns
 
 def test(q, bus, conn, stream):
-    conn.Connect()
-
-    q.expect('dbus-signal', signal='StatusChanged',
-            args=[cs.CONN_STATUS_CONNECTED, cs.CSR_REQUESTED])
-
     handles = {}
     handles['bob'] = conn.RequestHandles(1, ['bob@localhost'])[0]
 
