@@ -65,6 +65,7 @@ def worker(q, bus, conn, stream, should_decloak):
     q.unforbid_events(forbidden)
 
 if __name__ == '__main__':
-    exec_test(test)
+    exec_test(test,
+        params={cs.CONN_IFACE_GABBLE_DECLOAK + '.DecloakAutomatically': False})
     exec_test(lambda q, b, c, s: test(q, b, c, s, should_decloak=True),
         params={cs.CONN_IFACE_GABBLE_DECLOAK + '.DecloakAutomatically': True})
