@@ -47,8 +47,6 @@ class TlsAuthenticator(XmppAuthenticator):
         starttls = features.addElement((ns.NS_XMPP_TLS, 'starttls'))
         starttls.addElement('required')
 
-        mechanisms = features.addElement((ns.NS_XMPP_SASL, 'mechanisms'))
-        mechanism = mechanisms.addElement('mechanism', content='PLAIN')
         self.xmlstream.send(features)
 
         self.xmlstream.addOnetimeObserver("/starttls", self.tlsAuth)
@@ -64,19 +62,13 @@ class TlsAuthenticator(XmppAuthenticator):
             self.streamTLS()
 
     def tlsAuth(self, auth):
-        try:
-            file = open(CA_KEY, 'rb')
-            pem_key = file.read()
+        with open(CA_KEY, 'rb') as f:
+            pem_key = f.read()
             pkey = crypto.load_privatekey(crypto.FILETYPE_PEM, pem_key, "")
-        finally:
-            file.close()
 
-        try:
-            file = open(CA_CERT, 'rb')
-            pem_cert = file.read()
+        with open(CA_CERT, 'rb') as f:
+            pem_cert = f.read()
             cert = crypto.load_certificate(crypto.FILETYPE_PEM, pem_cert)
-        finally:
-            file.close()
 
         tls_ctx = ssl.CertificateOptions(privateKey=pkey, certificate=cert)
 
