@@ -14,17 +14,13 @@ def make_presence(jid, sha1sum):
     p = domish.Element((None, 'presence'))
     p['from'] = jid
     p['to'] = 'test@localhost/Resource'
-    x = p.addElement(('vcard-temp:x:update', 'x'))
+    x = p.addElement((ns.VCARD_TEMP_UPDATE, 'x'))
     x.addElement('photo', content=sha1sum)
     return p
 
 def test(q, bus, conn, stream):
-    conn.Connect()
-    _, event = q.expect_many(
-        EventPattern('dbus-signal', signal='StatusChanged',
-            args=[cs.CONN_STATUS_CONNECTED, cs.CSR_REQUESTED]),
-        EventPattern('stream-iq', to=None, query_ns=ns.ROSTER,
-            query_name='query'))
+    event = q.expect('stream-iq', to=None, query_ns=ns.ROSTER,
+            query_name='query')
 
     result = make_result_iq(stream, event.stanza)
     item = result.addElement('item')
